%define oname		zypp
%define major		1722
%define libname		%mklibname %oname %major
%define develname	%mklibname %oname -d

Name:		libzypp
Version:	17.31.1
Release:	%mkrel 5
Summary:	Zypp package management library
License:	GPLv2+
Group:		System/Libraries
URL:		https://en.opensuse.org/Zypp
Source0:        https://github.com/openSUSE/%{name}/archive/%{version}/%{name}-%{version}.tar.gz
# Fix underlinking. Not suited for upstream since the 2 libraries should probably be
# found by cmake and then added to libzypp input, not added directly as done here.
Patch0:		libzypp-17.15.0-underlinking.patch
# configure libzypp to keep multiple kernel packages with the same name
Patch2:		libzypp-installonly-kernels.patch
# do not put library in /usr/usr/lib64 ...
Patch3:		libzypp-17.28.1-library-destinatin.patch
#Patch4:		libzypp-ctime.patch
Patch5:		libzypp-yaml-cpp.patch
# Patches backported from upstream
BuildRequires:	asciidoc
BuildRequires:	boost-devel
BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	expat-devel
BuildRequires:	gpgme-devel
BuildRequires:	graphviz
BuildRequires:	libcurl-devel
BuildRequires:	libfcgi-devel
BuildRequires:	libproxy-devel
BuildRequires:	libsolv-devel
BuildRequires:	libudev-devel
BuildRequires:	libxml2-devel
BuildRequires:	nginx
BuildRequires:	openssl-devel
BuildRequires:	rpm-devel
BuildRequires:	zsync
BuildRequires:	cmake(yaml-cpp)
BuildRequires:	pkgconfig(sigc++-2.0)
BuildRequires:	pkgconfig(protobuf)
BuildRequires:	pkgconfig(protobuf-lite)

%description
ZYpp is a Linux software management engine with a powerful dependency
resolver and a convenient package management API.


%package -n %{oname}-common
Group:		System/Libraries
Summary:	Configuration files and utilities for %{name}

%description -n %{oname}-common
Configuration files and utilities for %{name}.


%package -n %{libname}
Group:		System/Libraries
Summary:	Zypp package manager library
Requires:	%{oname}-common = %{version}
Requires:	libsolv-tools

%description -n %{libname}
ZYpp is a Linux software management engine with a powerful dependency
resolver and a convenient package management API.


%package -n %{develname}
Group:		Development/C
Summary:	Development files for %{name}
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Requires:	libsolv-devel

%description -n %{develname}
Header files and development libraries for %{name}.


%package doc
Group:		Development/C
Summary:	Development documentation for %{name}
Requires:	%{name}-devel >= %{version}-%{release}
BuildArch:	noarch

%description doc
API documentation for %{name} generated using by doxygen.


%prep
%setup -q
%autopatch -p1

%build
%cmake -DFEDORA:BOOL=TRUE -DENABLE_BUILD_DOCS=ON -DENABLE_BUILD_TRANS=ON -DDISABLE_MEDIABACKEND_TESTS=ON
%cmake_build

%install
%cmake_install

%find_lang zypp

%files -n %{oname}-common -f zypp.lang
%dir %{_sysconfdir}/%{oname}
%config(noreplace) %{_sysconfdir}/%{oname}/%{oname}.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/zypp-history.lr
%{_mandir}/man5/locks.5.*
# not sure about the following
%{_sysconfdir}/%{oname}/systemCheck
%{_sysconfdir}/%{oname}/needreboot
%{_bindir}/zypp-CheckAccessDeleted
%{_bindir}/zypp-NameReqPrv
%{_libexecdir}/zypp/zypp-rpm
%{_datadir}/%{oname}
%{_mandir}/man1/zypp-CheckAccessDeleted.1.*
%{_mandir}/man1/zypp-NameReqPrv.1.*

%files -n %{libname}
%{_libdir}/%{name}.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/%{oname}
%{_includedir}/zypp-core/
%{_includedir}/zypp-curl/
%{_includedir}/zypp-media/
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/cmake/Modules/FindZypp.cmake
%{_datadir}/cmake/Modules/ZyppCommon.cmake

%files doc
%doc build/doc/autodoc/html
%doc %dir %_defaultdocdir/packages/libzypp
%doc %_defaultdocdir/packages/libzypp/*


%changelog
* Tue Dec 27 2022 daviddavid <daviddavid> 17.31.1-5.mga9
+ Revision: 1927159
- attempt patch to find yaml-cpp by config target
- rebuild for new yaml-cpp 0.7.0

* Sat Dec 24 2022 wally <wally> 17.31.1-4.mga9
+ Revision: 1926501
- rebuild for boost 1.81.0

* Thu Dec 22 2022 wally <wally> 17.31.1-3.mga9
+ Revision: 1925788
- rebuild for protobuf 21.12

* Mon Sep 26 2022 neoclust <neoclust> 17.31.1-2.mga9
+ Revision: 1892400
- Rebuild because of missing rpms

* Sat Sep 10 2022 neoclust <neoclust> 17.31.1-1.mga9
+ Revision: 1886458
- New version 17.31.1

* Mon Jul 04 2022 wally <wally> 17.28.4-7.mga9
+ Revision: 1867663
- add patch to fix build with std::time
- rebuild for boost 1.79.0

* Mon Apr 04 2022 umeabot <umeabot> 17.28.4-6.mga9
+ Revision: 1844024
- Mageia 9 Mass Rebuild

* Tue Dec 28 2021 wally <wally> 17.28.4-5.mga9
+ Revision: 1764998
- rebuild for protobuf 3.19.1

* Wed Dec 22 2021 wally <wally> 17.28.4-4.mga9
+ Revision: 1763311
- rebuild for missing pkgs in armv7hl

* Sun Dec 19 2021 wally <wally> 17.28.4-3.mga9
+ Revision: 1762598
- rebuild for boost 1.78.0

* Sat Oct 02 2021 wally <wally> 17.28.4-2.mga9
+ Revision: 1747914
- rebuild for openssl 3.0.0

* Fri Sep 24 2021 cjw <cjw> 17.28.4-1.mga9
+ Revision: 1746279
- 17.28.4
- fix default config to support multiple installed kernels with the same name

* Thu Sep 09 2021 wally <wally> 17.25.6-3.mga9
+ Revision: 1744633
- rebuild for boost 1.77.0

* Sun May 16 2021 wally <wally> 17.25.6-2.mga9
+ Revision: 1724775
- add patch to fix missing includes
- rebuild for boost 1.76.0

* Wed Jan 13 2021 neoclust <neoclust> 17.25.6-1.mga8
+ Revision: 1671653
- New version 17.25.6

* Thu Dec 31 2020 wally <wally> 17.20.0-6.mga8
+ Revision: 1666783
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 17.20.0-5.mga8
+ Revision: 1662025
- rebuild for boost 1.74.0

* Sun May 03 2020 wally <wally> 17.20.0-4.mga8
+ Revision: 1578078
- rebuild for boost 1.73.0

* Wed Feb 19 2020 umeabot <umeabot> 17.20.0-3.mga8
+ Revision: 1544804
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 17.20.0-2.mga8
+ Revision: 1483395
- rebuild for boost 1.72.0

* Sun Jan 19 2020 cjw <cjw> 17.20.0-1.mga8
+ Revision: 1481602
- 17.20.0
+ wally <wally>
- build with new cmake macros

* Wed Oct 30 2019 cjw <cjw> 17.15.0-1.mga8
+ Revision: 1456643
- 17.15.0
- fix "underlinking"

* Mon Sep 16 2019 tv <tv> 17.14.0-1.mga8
+ Revision: 1442260
- new release
- major is now 1712
-"fix" underlinking
- fix for rpm-4.15
- enable translations & docs
- rebuild for rpm-4.15
- rebuild for rpm-4.15

* Sat Jan 05 2019 cjw <cjw> 17.9.0-1.mga7
+ Revision: 1349390
- 17.9.0

* Fri Jan 25 2013 cjw <cjw> 11.6.3-4.mga3
+ Revision: 392200
- patch2: fix build with gcc 4.7

* Sat Jan 12 2013 umeabot <umeabot> 11.6.3-3.mga3
+ Revision: 358755
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Dec 18 2012 tv <tv> 11.6.3-2.mga3
+ Revision: 332294
- rebuild for new rpm

* Sun Jul 01 2012 colin <colin> 11.6.3-1.mga3
+ Revision: 266250
- New version: 11.6.3 (needed for new gcc-4.7)
- Switch to libsolv from libsatsolver
- Rebuild for new libudev major

* Sun Jun 10 2012 tv <tv> 9.1.2-4.mga3
+ Revision: 259368
- rebuild for new rpm-4.10.0

* Mon Feb 13 2012 dmorgan <dmorgan> 9.1.2-3.mga2
+ Revision: 208372
- Rebuild against rpm 4.9.1.2

* Fri Sep 02 2011 tv <tv> 9.1.2-2.mga2
+ Revision: 137803
- make the huge doc subpackage be noarch

* Fri Jun 17 2011 cjw <cjw> 9.1.2-1.mga2
+ Revision: 108554
- add BuildRequires: graphviz
- imported package libzypp

